pub struct Rsa<'d, Dm: DriverMode> { /* private fields */ }Expand description
RSA peripheral driver.
Implementations
Sourceimpl<'d> Rsa<'d, Blocking>
impl<'d> Rsa<'d, Blocking>
Sourcepub fn new(rsa: RSA<'d>) -> Self
pub fn new(rsa: RSA<'d>) -> Self
Creates a new instance in Blocking mode.
Optionally an interrupt handler can be bound.
Sourcepub fn into_async(self) -> Rsa<'d, Async>
pub fn into_async(self) -> Rsa<'d, Async>
Reconfigures the RSA driver to operate in asynchronous mode.
Sourcepub fn enable_disable_interrupt(&mut self, enable: bool)
pub fn enable_disable_interrupt(&mut self, enable: bool)
Enables or disables the RSA interrupt.
When enabled rsa peripheral would generate an interrupt when a operation is finished.
Sourcepub fn set_interrupt_handler(&mut self, handler: InterruptHandler)
Available on crate feature unstable only.
pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)
unstable only.Registers an interrupt handler for the RSA peripheral.
Replaces any previously registered interrupt handlers.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.